==> jc-1.4.0.tar.gz: soot/baf/internal/BCmpInst.h <==
// public class soot.baf.internal.BCmpInst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 34018fa9b43e3c40 soot_baf_internal_AbstractOpTypeInst
// @dep_class 4e05efcf231f2ed4 soot_baf_internal_BCmpInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractOpTypeInst

#include "soot/baf/internal/AbstractOpTypeInst.h"

#ifndef _JC_soot_baf_internal_BCmpInst_H_
#define _JC_soot_baf_internal_BCmpInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BCmpInst$sub_refs	_jc_soot_baf_internal_BCmpInst$sub_refs;
typedef struct _jc_soot_baf_internal_BCmpInst$sub_nonrefs	_jc_soot_baf_internal_BCmpInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BCmpInst$refs	_jc_soot_baf_internal_BCmpInst$refs;
typedef struct _jc_soot_baf_internal_BCmpInst$nonrefs	_jc_soot_baf_internal_BCmpInst$nonrefs;
typedef struct _jc_soot_baf_internal_BCmpInst$object	_jc_soot_baf_internal_BCmpInst$object;

typedef const struct _jc_soot_baf_internal_BCmpInst$vmethods	_jc_soot_baf_internal_BCmpInst$vmethods;
typedef const struct _jc_soot_baf_internal_BCmpInst$vtable	_jc_soot_baf_internal_BCmpInst$vtable;
typedef const struct _jc_soot_baf_internal_BCmpInst$vtype	_jc_soot_baf_internal_BCmpInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BCmpInst$method$_init$39d637909e460d2e(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *, struct _jc_soot_Type$object *);

// Virtual methods
extern void _jc_soot_baf_internal_BCmpInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BCmpInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *);
extern jint _jc_soot_baf_internal_BCmpInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *);
extern jint _jc_soot_baf_internal_BCmpInst$method$getInMachineCount$53f8938c85f21ad5(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BCmpInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *);
extern jint _jc_soot_baf_internal_BCmpInst$method$getOutCount$de2aea04cd3e0d65(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *);
extern jint _jc_soot_baf_internal_BCmpInst$method$getOutMachineCount$382bb5439d011100(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BCmpInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BCmpInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_internal_BCmpInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BCmpInst$method_info$getInMachineCount$53f8938c85f21ad5;
extern _jc_method _jc_soot_baf_internal_BCmpInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BCmpInst$method_info$getOutCount$de2aea04cd3e0d65;
extern _jc_method _jc_soot_baf_internal_BCmpInst$method_info$getOutMachineCount$382bb5439d011100;

// Virtual methods structure
struct _jc_soot_baf_internal_BCmpInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *);
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *);
	jint	(*getInMachineCount$53f8938c85f21ad5)(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *);
	jint	(*getOutCount$de2aea04cd3e0d65)(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *);
	jint	(*getOutMachineCount$382bb5439d011100)(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *);
};

// Vtable
struct _jc_soot_baf_internal_BCmpInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractOpTypeInst$vmethods	soot_baf_internal_AbstractOpTypeInst;
	_jc_soot_baf_internal_BCmpInst$vmethods	soot_baf_internal_BCmpInst;
};

// Vtype
struct _jc_soot_baf_internal_BCmpInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BCmpInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BCmpInst$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BCmpInst$refs {
    _jc_soot_baf_internal_BCmpInst$sub_refs	soot_baf_internal_BCmpInst;
    _jc_soot_baf_internal_AbstractOpTypeInst$sub_refs	soot_baf_internal_AbstractOpTypeInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BCmpInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BCmpInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractOpTypeInst$sub_nonrefs	soot_baf_internal_AbstractOpTypeInst;
    _jc_soot_baf_internal_BCmpInst$sub_nonrefs	soot_baf_internal_BCmpInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BCmpInst$object {
	_jc_soot_baf_internal_BCmpInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BCmpInst$vtype	*vtype;
	_jc_soot_baf_internal_BCmpInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BCmpInst$vtype _jc_soot_baf_internal_BCmpInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BCmpInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BCmpInst$class_object;

#endif	/* _JC_soot_baf_internal_BCmpInst_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/BCmpInst.h <==
// public class soot.baf.internal.BCmpInst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 34018fa9b43e3c40 soot_baf_internal_AbstractOpTypeInst
// @dep_class 4e05efcf231f2ed4 soot_baf_internal_BCmpInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractOpTypeInst

#include "soot/baf/internal/AbstractOpTypeInst.h"

#ifndef _JC_soot_baf_internal_BCmpInst_H_
#define _JC_soot_baf_internal_BCmpInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BCmpInst$sub_refs	_jc_soot_baf_internal_BCmpInst$sub_refs;
typedef struct _jc_soot_baf_internal_BCmpInst$sub_nonrefs	_jc_soot_baf_internal_BCmpInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BCmpInst$refs	_jc_soot_baf_internal_BCmpInst$refs;
typedef struct _jc_soot_baf_internal_BCmpInst$nonrefs	_jc_soot_baf_internal_BCmpInst$nonrefs;
typedef struct _jc_soot_baf_internal_BCmpInst$object	_jc_soot_baf_internal_BCmpInst$object;

typedef const struct _jc_soot_baf_internal_BCmpInst$vmethods	_jc_soot_baf_internal_BCmpInst$vmethods;
typedef const struct _jc_soot_baf_internal_BCmpInst$vtable	_jc_soot_baf_internal_BCmpInst$vtable;
typedef const struct _jc_soot_baf_internal_BCmpInst$vtype	_jc_soot_baf_internal_BCmpInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BCmpInst$method$_init$39d637909e460d2e(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_baf_internal_BCmpInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BCmpInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BCmpInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BCmpInst$method$getInMachineCount$53f8938c85f21ad5(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BCmpInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BCmpInst$method$getOutCount$de2aea04cd3e0d65(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BCmpInst$method$getOutMachineCount$382bb5439d011100(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BCmpInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BCmpInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_internal_BCmpInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BCmpInst$method_info$getInMachineCount$53f8938c85f21ad5;
extern _jc_method _jc_soot_baf_internal_BCmpInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BCmpInst$method_info$getOutCount$de2aea04cd3e0d65;
extern _jc_method _jc_soot_baf_internal_BCmpInst$method_info$getOutMachineCount$382bb5439d011100;

// Virtual methods structure
struct _jc_soot_baf_internal_BCmpInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *) _JC_JCNI_ATTR;
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *) _JC_JCNI_ATTR;
	jint	(*getInMachineCount$53f8938c85f21ad5)(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *) _JC_JCNI_ATTR;
	jint	(*getOutCount$de2aea04cd3e0d65)(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *) _JC_JCNI_ATTR;
	jint	(*getOutMachineCount$382bb5439d011100)(_jc_env *, struct _jc_soot_baf_internal_BCmpInst$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_BCmpInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractOpTypeInst$vmethods	soot_baf_internal_AbstractOpTypeInst;
	_jc_soot_baf_internal_BCmpInst$vmethods	soot_baf_internal_BCmpInst;
};

// Vtype
struct _jc_soot_baf_internal_BCmpInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BCmpInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BCmpInst$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BCmpInst$refs {
    _jc_soot_baf_internal_BCmpInst$sub_refs	soot_baf_internal_BCmpInst;
    _jc_soot_baf_internal_AbstractOpTypeInst$sub_refs	soot_baf_internal_AbstractOpTypeInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BCmpInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BCmpInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractOpTypeInst$sub_nonrefs	soot_baf_internal_AbstractOpTypeInst;
    _jc_soot_baf_internal_BCmpInst$sub_nonrefs	soot_baf_internal_BCmpInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BCmpInst$object {
	_jc_soot_baf_internal_BCmpInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BCmpInst$vtype	*vtype;
	_jc_soot_baf_internal_BCmpInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BCmpInst$vtype _jc_soot_baf_internal_BCmpInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BCmpInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BCmpInst$class_object;

#endif	/* _JC_soot_baf_internal_BCmpInst_H_ */
